require 'rails_helper'

# This spec was generated by rspec-rails when you ran the scaffold generator.
# It demonstrates how one might use RSpec to specify the controller code that
# was generated by Rails when you ran the scaffold generator.
#
# It assumes that the implementation code is generated by the rails scaffold
# generator.  If you are using any extension libraries to generate different
# controller code, this generated spec may or may not pass.
#
# It only uses APIs available in rails and/or rspec-rails.  There are a number
# of tools you can use to make these specs even more expressive, but we're
# sticking to rails and rspec-rails APIs to keep things simple and stable.
#
# Compared to earlier versions of this generator, there is very limited use of
# stubs and message expectations in this spec.  Stubs are only used when there
# is no simpler way to get a handle on the object needed for the example.
# Message expectations are only used when there is no simpler way to specify
# that an instance is receiving a specific message.

RSpec.describe MailManager::MailingListsController, :type => :controller do
  render_views
  routes {MailManager::Engine.routes}

  # This should return the minimal set of attributes required to create a valid
  # MailManager::MailingList. As you add validations to MailManager::MailingList, be sure to
  # adjust the attributes here as well.
  let(:valid_attributes) {
    FactoryGirl.attributes_for(:mailing_list)
  }

  let(:invalid_attributes) {
    FactoryGirl.attributes_for(:mailing_list, name: nil)
  }

  # This should return the minimal set of values that should be in the session
  # in order to pass any filters (e.g. authentication) defined in
  # MailManager::MailingListsController. Be sure to keep this updated too.
  let(:valid_session) { {} }

  describe "GET #index" do
    it "assigns all mailing_lists as @mailing_lists" do
      mailing_list = MailManager::MailingList.create! valid_attributes
      get :index, {}, valid_session
      expect(assigns(:mailing_lists)).to eq([mailing_list])
      expect(response.body).to have_content "Listing Mailing Lists"
    end
  end

  describe "GET #show" do
    it "assigns the requested mailing_list as @mailing_list" do
      mailing_list = MailManager::MailingList.create! valid_attributes
      get :show, {:id => mailing_list.to_param}, valid_session
      expect(assigns(:mailing_list)).to eq(mailing_list)
    end
  end

  describe "GET #new" do
    it "assigns a new mailing_list as @mailing_list" do
      get :new, {}, valid_session
      expect(assigns(:mailing_list)).to be_a_new(MailManager::MailingList)
      expect(response.body).to have_content "New Mailing List"
    end
  end

  describe "GET #edit" do
    it "assigns the requested mailing_list as @mailing_list" do
      mailing_list = MailManager::MailingList.create! valid_attributes
      get :edit, {:id => mailing_list.to_param}, valid_session
      expect(assigns(:mailing_list)).to eq(mailing_list)
      expect(response.body).to have_content "Editing #{mailing_list.name}"
    end
  end

  describe "POST #create" do
    context "with valid params" do
      it "creates a new MailManager::MailingList" do
        expect {
          post :create, {:mailing_list => valid_attributes}, valid_session
        }.to change(MailManager::MailingList, :count).by(1)
      end

      it "assigns a newly created mailing_list as @mailing_list" do
        post :create, {:mailing_list => valid_attributes}, valid_session
        expect(assigns(:mailing_list)).to be_a(MailManager::MailingList)
        expect(assigns(:mailing_list)).to be_persisted
      end

      it "redirects to the created mailing_list" do
        post :create, {:mailing_list => valid_attributes}, valid_session
        expect(response).to redirect_to(mailing_lists_path)
      end
    end

    context "with invalid params" do
      it "assigns a newly created but unsaved mailing_list as @mailing_list" do
        post :create, {:mailing_list => invalid_attributes}, valid_session
        expect(assigns(:mailing_list)).to be_a_new(MailManager::MailingList)
      end

      it "re-renders the 'new' template" do
        post :create, {:mailing_list => invalid_attributes}, valid_session
        expect(response).to render_template("new")
      end
    end
  end

  describe "PUT #update" do
    context "with valid params" do
      let(:new_attributes) {
        FactoryGirl.attributes_for(:mailing_list)
      }

      it "updates the requested mailing_list" do
        mailing_list = MailManager::MailingList.create! valid_attributes
        put :update, {:id => mailing_list.to_param, :mailing_list => new_attributes}, valid_session
        mailing_list = MailManager::MailingList.find(mailing_list.id) 
        expect(mailing_list).to match_attributes(new_attributes)
      end

      it "assigns the requested mailing_list as @mailing_list" do
        mailing_list = MailManager::MailingList.create! valid_attributes
        put :update, {:id => mailing_list.to_param, :mailing_list => valid_attributes}, valid_session
        expect(assigns(:mailing_list)).to eq(mailing_list)
      end

      it "redirects to the mailing_list" do
        mailing_list = MailManager::MailingList.create! valid_attributes
        put :update, {:id => mailing_list.to_param, :mailing_list => valid_attributes}, valid_session
        expect(response).to redirect_to(mailing_lists_path)
      end
    end

    context "with invalid params" do
      it "assigns the mailing_list as @mailing_list" do
        mailing_list = MailManager::MailingList.create! valid_attributes
        put :update, {:id => mailing_list.to_param, :mailing_list => invalid_attributes}, valid_session
        expect(assigns(:mailing_list)).to eq(mailing_list)
      end

      it "re-renders the 'edit' template" do
        mailing_list = MailManager::MailingList.create! valid_attributes
        put :update, {:id => mailing_list.to_param, :mailing_list => invalid_attributes}, valid_session
        expect(response).to render_template("edit")
      end
    end
  end

  describe "DELETE #destroy" do
    it "destroys the requested mailing_list" do
      mailing_list = MailManager::MailingList.create! valid_attributes
      expect {
        delete :destroy, {:id => mailing_list.to_param}, valid_session
      }.to change(MailManager::MailingList, :count).by(-1)
    end

    it "redirects to the mailing_lists list" do
      mailing_list = MailManager::MailingList.create! valid_attributes
      delete :destroy, {:id => mailing_list.to_param}, valid_session
      expect(response).to redirect_to(mailing_lists_url)
    end

    it "only soft deletes the mailing list" do
      mailing_list = MailManager::MailingList.create! valid_attributes
      expect {
        delete :destroy, {:id => mailing_list.to_param}, valid_session
      }.to change(MailManager::MailingList.deleted, :count).by(1)
    end
  end

end
